@@ -1,4 +1,5 @@
 from django.db import models, transaction
+from django.urls import reverse
 
 from nautobot.core.models.generics import PrimaryModel
 from nautobot.dcim.models import Device, Interface
@@ -29,8 +30,8 @@ class VRFPrimaryVLAN(PrimaryModel):
 
 
 class EthernetSegment(PrimaryModel):
-    segment_id = models.IntegerField(unique=True)
-    name = models.CharField(max_length=256)
+    segment_id = models.IntegerField(unique=True, verbose_name="Ethernet Segment ID")
+    name = models.CharField(max_length=256, unique=True)
 
     csv_headers = ["segment_id", "name"]
 
@@ -47,6 +48,9 @@ class EthernetSegment(PrimaryModel):
     def __str__(self):
         return "{} ({})".format(self.name, self.segment_id)
 
+    def get_absolute_url(self):
+        return reverse("plugins:nautobot_evpn:es", args=[self.pk])
+
 
 class EthernetSegmentMembership(PrimaryModel):
     segment = models.ForeignKey(
