@@ -6,8 +6,12 @@ from django.shortcuts import get_object_or_404, redirect, render, reverse
 from django.utils.decorators import method_decorator
 from django.views.generic import View
 from django.views.generic.edit import CreateView
+from django_tables2 import Column
+
+from nautobot.dcim.choices import InterfaceTypeChoices
+from nautobot.dcim.tables import InterfaceTable
 from nautobot.ipam.models import VLAN, VRF
-from nautobot.core.views.generic import BulkImportView, ObjectListView, ObjectEditView
+from nautobot.core.views.generic import BulkImportView, ObjectListView, ObjectEditView, ObjectView
 
 from . import tables
 from .forms import (
@@ -129,7 +133,52 @@ class EthernetSegmentListView(PermissionRequiredMixin, ObjectListView):
     queryset = EthernetSegment.objects.all()
     table = tables.EthernetSegmentTable
     action_buttons = ()
-    template_name="nautobot_evpn/ethernetsegment_list.html"
+    template_name = "nautobot_evpn/ethernetsegment_list.html"
+
+
+class ExtendedInterfaceTable(InterfaceTable):
+
+    class Meta(InterfaceTable.Meta):
+        pass
+
+    def __init__(self, physical_interfaces, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.physical_interfaces = list(physical_interfaces)
+        self.columns.show("underlaying_interface_type")
+
+    underlaying_interface_type = Column(
+        "Underlaying Interface Type",
+        empty_values=()
+    )
+
+    def render_underlaying_interface_type(self, value, record):
+        print(value, record)
+        physical_interface = next(filter(lambda p: p.lag == record, self.physical_interfaces), None)
+        c = InterfaceTypeChoices.as_dict().get(physical_interface.type)
+        return c if physical_interface else None
+
+
+
+class EthernetSegmentView(ObjectView):
+    queryset = EthernetSegment.objects.all()
+
+    def get_extra_context(self, request, instance):
+        attached_interfaces = Interface.objects.filter(ethernetsegmentmembership__segment=instance).restrict(
+            request.user, "view")
+
+        physical_interfaces = Interface.objects.filter(lag__in=attached_interfaces)
+
+        attached_interfaces_table = ExtendedInterfaceTable(
+            physical_interfaces,
+            attached_interfaces,
+            orderable=False,
+        )
+        attached_interfaces_table.columns.show("untagged_vlan")
+        attached_interfaces_table.columns.show("tagged_vlans")
+
+        return {
+            "attached_interfaces_table": attached_interfaces_table,
+        }
 
 
 class EthernetSegmentAddView(PermissionRequiredMixin, ObjectEditView):
